#!/bin/bash

# define main function
MAIN_INSTALL="main_install"
MAIN_UPGRADE="main_upgrade"
MAIN_UNINST="main_uninst"
# define each page's name
PAGE_MARIADB5="page_mariadb5"
PAGE_MARIADB10="page_mariadb10"
PAGE_RESTORE="page_restore"
PAGE_DB="page_db"
PAGE_UNINST="page_uninst"
DEFAULT="enu"
# set out file name
OUTPUT_INSTALL="install_uifile"
OUTPUT_UPGRADE="upgrade_uifile"
OUTPUT_UNINST="uninstall_uifile"
INIT_DB_NAME="" # need to be overwrited
INIT_DB_USER="" # need to be overwrited
INFO_FILE="" # need to be overwrited
BACKUP_PATH="" # need to be overwrited
# here to define what page is necessary for each stage: install, upgrade, and uninstall
PAGE_INST="$PAGE_MARIADB5 $PAGE_RESTORE $PAGE_MARIADB10 $PAGE_DB $MAIN_INSTALL"
PAGE_UPGRADE="$PAGE_MARIADB5 $PAGE_MARIADB10 $PAGE_DB $MAIN_UPGRADE"
PAGE_UNINST="$PAGE_UNINST $MAIN_UNINST"
MIGRATE_DB_VERSION="-1"

MainCreate()
{
	local output="$1"
	local pages="$2"
	local main_function="$3"
	local lan
	for dir in lang/*; do
		lan=$(basename "$dir")
		cat "wizard_common" "wizard_customized" > "${output}_${lan}.sh"
		CustomWizCreate "${output}_${lan}.sh"
		cat "lang/$lan" $pages "$main_function" >> "${output}_${lan}.sh"
	done
	chmod +x "${output}"*.sh
	cp -a "${output}_${DEFAULT}.sh" "${output}.sh"
}

NeedMigrateDB()
{
	local version="$1"
	if [ -z "$version" ] || [ "$version" -le "$MIGRATE_DB_VERSION" ]; then
		return 0
	fi
	return 1
}

CustomHasRunWebsiteSetup()
{
	local path="$1"
	[ -s "$path/$CONF_FILE" ]
}

CustomWizCreate()
{
	:
}

CustomSetBackupPath()
{
	BACKUP_PATH="$(CustomGetBackupPkgPath)"
}

CustomMainInstall()
{
	:
}

CustomGetValueFromMetaFile()
{
	local key="$1"
	local backup_info="/var/packages/.$PKG_DIR.conf"
	local syno_conf="/var/packages/$PKG_NAME/synology.conf"
	local record_file=""

	if [ -s "$INFO_FILE" ]; then
		record_file="$INFO_FILE"
	elif [ -s "$backup_info" ]; then
		record_file="$backup_info"
	elif [ -s "$syno_conf" ]; then
		record_file="$syno_conf"
	fi
	get_key_value "$record_file" "$key"
}

CustomGetBackupPrefix()
{
	local backup_prefix="/$(readlink /var/services/web | cut -d/ -f2)/@appstore/.$PKG_DIR"
	echo "$backup_prefix"
}

CustomGetBackupPkgPath()
{
	local backup_pkg_path="$(CustomGetBackupPrefix)/$PKG_DIR"
	echo "$backup_pkg_path"
}

# we define pages in fuction not in global variables,
# because functions in wizard steps will be merged after calling MainCreate.
CustomSetPages()
{
	NEW_INSTALL_PAGES="$(PageM10),$(PageDB)"
	RESTORE_PAGES="$(PageRestore),$(PageM10),$(PageDB)"
	MIGRATE_PAGES="$(PageM5),$(PageRestore),$(PageM10),$(PageDB)"
}

CustomParseDBConf()
{
	:
}

CustomGetDBName()
{
	:
}

CustomGetDBUser()
{
	:
}

CustomGetDBPass()
{
	:
}

CustomPageActivate()
{
	:
}
#!/bin/bash
# Copyright (c) 2000-2017 Synology Inc. All rights reserved.

PKG_NAME="DokuWiki"
PKG_DIR="dokuwiki"
WEBSITE_ROOT="/var/services/web/$PKG_DIR"
INFO_FILE="/usr/syno/etc/packages/$PKG_NAME/$PKG_DIR.conf"
PAGE_INST="$PAGE_RESTORE $MAIN_INSTALL"
PAGE_UPGRADE="$MAIN_UPGRADE"
CONF_FILE="conf/local.php"

CustomSetPages()
{
	NEW_INSTALL_PAGES=""
	RESTORE_PAGES="$(PageRestore)"
}

CustomHasRunWebsiteSetup()
{
	# initial setup for Dokuwiki is optional, it does not indicate the need for upgrade migration
	# there is no difference between setup-done and setup-required
	true
}

wizard_db_settings="Configurar banco de dados do DokuWiki"
wizard_db_name_desc="Digite o nome do banco de dados do DokuWiki."
wizard_db_name_label="Nome do banco de dados"
wizard_m10_desc="Insira as credenciais de administrador do MariaDB 10 para prosseguir com as configurações do banco de dados do DokuWiki."
wizard_admin_acc="Conta"
wizard_admin_pass="Senha"
wizard_set_db_desc="Crie uma conta nova e exclusiva de banco de dados para o DokuWiki usar dados existentes/novos."
wizard_set_data_title="Configurar DokuWiki"
wizard_found_backup="Selecione um método parar importar os dados."
wizard_decide_restore="DokuWiki o bando de dados já existe.<br>Selecione uma das seguintes ações:"
wizard_restore="Usar dados existentes"
wizard_create_new="Limpar instalação (todos os dados existentes, incluindo arquivos de configuração e o banco de dados, serão removidos.)"
wizard_db_user_account_desc="Conta de usuário de banco de dados"
wizard_db_user_password_desc="Senha do usuário de banco de dados"
wizard_migrate_note="A versão mais recente do DokuWiki só oferece suporte ao MariaDB 10.<br>O sistema detectou um banco de dados já existente do MariaDB 5.<br>Na próxima etapa, o banco de dados será migrado do MariaDB 5 para o MariaDB 10.<br><br>Insira as credenciais de administrador do MariaDB 5 para prosseguir com a instalação."
wizard_migrate_title="Migrar banco de dados do DokuWiki"
wizard_remove_msql_title="Remover banco de dados do DokuWiki"
wizard_remove_msql_desc="Se o banco de dados do DokuWiki for removido, todos os dados serão excluídos."
wizard_msql_password_desc_remove="Digite as credenciais do administrador de banco de dados para remover o banco de dados do DokuWiki."
wizard_admin_acc="Conta"
wizard_admin_pass="Senha"
wizard_decide_restore="DokuWiki dados já existem.<br>Selecione uma das seguintes ações:"
wizard_create_new="Limpar instalação (Todos os dados existentes serão removidos.)"
wizard="Limpar instalação (Todos os dados existentes serão removidos.)"
wizard_remove_data_title="Remover dados da DokuWiki"
wizard_remove_data_desc="Ao remover o DokuWiki, todos os artigos e configurações serão excluídos."
wizard_remove_data_title="Remover dados da DokuWiki"
PageRestore()
{
cat << EOF
{
	"step_title": "$wizard_found_backup",
	"items": [{
		"type": "singleselect",
		"desc": "$wizard_decide_restore",
		"subitems": [{
			"key": "restore_backup",
			"desc": "$wizard_restore",
			"defaultValue": true
		}, {
			"desc": "$wizard_create_new",
			"defaultValue": false
		}]
	}]
}
EOF
}

main()
{
	local install_page=""

	CustomSetPages # set: MIGRATE_PAGES RESTORE_PAGES NEW_INSTALL_PAGES
	CustomSetBackupPath # set BACKUP_PATH
	CustomMainInstall

	DEFAULT_RESTORE=false
	NEED_MIGRATE=false
	MARIADB_VER="m10"
	DB_NAME=$(CustomGetDBName "$BACKUP_PATH")
	DB_USER=$(CustomGetDBUser "$BACKUP_PATH")

	if CustomHasRunWebsiteSetup "$BACKUP_PATH"; then
		local version="$(CustomGetValueFromMetaFile "version" | cut -s -d- -f2)"
		if NeedMigrateDB "$version"; then # check if needing to migrate MariaDB 5
			NEED_MIGRATE=true
			MARIADB_VER="m5"
			install_page="$MIGRATE_PAGES"
		else
			install_page="$RESTORE_PAGES"
		fi
	else
		install_page="$NEW_INSTALL_PAGES"
	fi

	echo "[$install_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
main()
{
	local install_page=""

	CustomSetPages # set: MIGRATE_PAGES RESTORE_PAGES NEW_INSTALL_PAGES
	CustomSetBackupPath # set BACKUP_PATH
	CustomMainInstall

	DEFAULT_RESTORE=false
	NEED_MIGRATE=false
	MARIADB_VER="m10"
	DB_NAME=$(CustomGetDBName "$BACKUP_PATH")
	DB_USER=$(CustomGetDBUser "$BACKUP_PATH")

	if CustomHasRunWebsiteSetup "$BACKUP_PATH"; then
		local version="$(CustomGetValueFromMetaFile "version" | cut -s -d- -f2)"
		if NeedMigrateDB "$version"; then # check if needing to migrate MariaDB 5
			NEED_MIGRATE=true
			MARIADB_VER="m5"
			install_page="$MIGRATE_PAGES"
		else
			install_page="$RESTORE_PAGES"
		fi
	else
		install_page="$NEW_INSTALL_PAGES"
	fi

	echo "[$install_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
